@@ -8,7 +8,7 @@ import random
 import math
 import re as rep
 
-x,y,z,t = symbols("x y z t")
+m,n,p,t = symbols("m n p t")
 
 def conv(elemento):
     if elemento == '' or elemento == '+' or elemento == '  ' or elemento == ' + 'or elemento == ' ':
@@ -140,7 +140,7 @@ def extraer(cadena):
 
 def ecualist(ecua):
 
-    ecuacion = Eq(1*x+2*y+5*z,3)
+    ecuacion = Eq(1*m+2*n+5*p,3)
 
 
     if type(ecua)==type(ecuacion):
@@ -238,7 +238,7 @@ def sust(elemen,sub):
 
 def listaplanos(lista):
     planos = []
-    ecuacion = Eq(1*x+2*y+5*z,3)
+    ecuacion = Eq(1*m+2*n+5*p,3)
 
     for elemen in lista:
         if type(elemen) == str or type(elemen)==type(ecuacion):
@@ -313,7 +313,7 @@ def plot3D(*args):
     ye = [0]
     ze = [0.3,-0.3]
     Ma = Matrix([1,2,3])
-    ecuacion = Eq(1*x+2*y+5*z,3)
+    ecuacion = Eq(1*m+2*n+5*p,3)
     l = []
 
 
@@ -341,11 +341,10 @@ def plot3D(*args):
             ye.append(d/(P[1]+0.1))
             ze.append(d/(P[2]+0.1))
 
-            xe.append(P[0])
-            ye.append(P[1])
-            ze.append(P[2])
-
-            ze.append(d)   
+            #xe.append(P[0])
+            #ye.append(P[1])
+            #ze.append(P[2])
+            #ze.append(d)   
 
             l.append(V) 
 
@@ -556,11 +555,11 @@ def plot3D(*args):
             ye.append(d/(P[1]+0.1))
             ze.append(d/(P[2]+0.1))
 
-            xe.append(P[0])
-            ye.append(P[1])
-            ze.append(P[2])
+            #xe.append(P[0])
+            #ye.append(P[1])
+            #ze.append(P[2])
+            #ze.append(d)
 
-            ze.append(d)
             l.append(V)
 
         if type(V) == dict:
@@ -631,7 +630,7 @@ def plot3D(*args):
                     ye.append(sust(V[y],-1*tiempo))
                     ze.append(sust(V[z],-1*tiempo))
 
-            if (V[x] + V[y] + V[z]) == int or (V[x] + V[y] + V[z]) == float:
+            if type(V[x] + V[y] + V[z]) == int or type(V[x] + V[y] + V[z]) == float:
                 
                 xe.append(V[x])
                 ye.append(V[y])
